@@ -10,7 +10,6 @@ import urllib
 import ssl
 import zipfile
 import re
-import pkg_resources
 import subprocess
 import webbrowser
 import psutil
@@ -31,6 +30,8 @@ from qt_material import apply_stylesheet
 if platform.system() != "Windows":
     import grp
 
+from meshtastic_flasher.version import __version__
+
 MESHTASTIC_LOGO_FILENAME = "logo.png"
 MESHTASTIC_COLOR_DARK = "#2C2D3C"
 MESHTASTIC_COLOR_GREEN = "#67EA94"
@@ -38,11 +39,14 @@ MESHTASTIC_COLOR_GREEN = "#67EA94"
 MESHTATIC_REPO = 'meshtastic/Meshtastic-device'
 
 # see https://stackoverflow.com/questions/31836104/pyinstaller-and-onefile-how-to-include-an-image-in-the-exe-file
+# but had to tweak for pypi
 def get_path(filename):
     """return the path to the logo file"""
     if hasattr(sys, "_MEIPASS"):
         return os.path.join(sys._MEIPASS, filename)
-    return filename
+    # return path to where this file is located
+    path = os.path.dirname(os.path.abspath(__file__))
+    return os.path.join(path, filename)
 
 def populate_tag_in_firmware_dropdown(tag):
     """Populate this tag in the firmware dropdown?"""
@@ -66,8 +70,7 @@ class Form(QDialog):
         self.nrf = False
         self.device = None
 
-        version = pkg_resources.get_distribution("meshtastic_flasher").version
-        self.setWindowTitle(f"Meshtastic Flasher v{version}")
+        self.setWindowTitle(f"Meshtastic Flasher v{__version__}")
 
         # Create widgets
         self.select_firmware = QPushButton("SELECT FIRMWARE")
